@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+import os
 import tkinter
 from dataclasses import dataclass
 from PIL import Image, ImageTk
@@ -6,6 +7,7 @@ from .lib import Card, Hand, Player, Dealer, Shoe, get_correct_play
 
 
 N_CARDS_MAX = 9
+IMG_PATH = f'{os.path.dirname(__file__)}/images/'
 
 
 @dataclass
@@ -41,6 +43,7 @@ class Game:
         self.gui.slider.configure(state=tkinter.DISABLED)
         self.hide_all_chips()
         self.hide_fingers()
+        self.clean_player_slots()
         self.player.init_count()
         self.player.hands = []
         if self.shoe.n_cards < 52:
@@ -55,13 +58,15 @@ class Game:
         self.show_buttons()
         self.hide_buttons(('deal',))
         self.show()
-        self.display_player_hands()
         self.active_slot = hand.slot
         self.display_stack()
         self.enable_correct_buttons(hand)
         self.display_chip(hand, 0)
         if hand.is_blackjack:
             self.resolve_blackjack()
+            self.display_player_cards(hand, rotate_last=True)
+        else:
+            self.display_player_cards(hand)
         if self.dealer.cards[0].label == 'A':
             self.hide_buttons(('surrender', ))
 
@@ -87,7 +92,7 @@ class Game:
         hand.deal(self.shoe, self.gui.shoe_progress)
         self.display_chip(hand, 1)
         hand.is_finished = True
-        self.display_player_hands()
+        self.display_player_cards(hand, rotate_last=True)
         if hand.sum > 21:
             self.hide(hand)
             self.hide_chips(hand)
@@ -117,12 +122,14 @@ class Game:
                 return
         self.hide_buttons(('surrender', 'double'))
         hand.deal(self.shoe, self.gui.shoe_progress)
-        self.display_player_hands()
+        if hand.sum == 21:
+            self.display_player_cards(hand, rotate_last=True)
+            hand.is_finished = True
+        else:
+            self.display_player_cards(hand)
         if hand.is_over is True:
             self.hide(hand)
             self.hide_chips(hand)
-        if hand.sum == 21:
-            hand.is_finished = True
         if hand.is_finished is False:
             self.enable_correct_buttons(hand)
         else:
@@ -205,22 +212,22 @@ class Game:
         for hand in self.player.hands:
             if hand.is_blackjack is True and self.dealer.is_blackjack is False:
                 self.player.stack += hand.bet * 2.5
-                result = f'Win by Blackjack!'
+                result = f'WIN BY BLACKJACK!'
                 self._display_chips(hand, bj=True)
             elif hand.is_blackjack is True and self.dealer.is_blackjack is True:
                 self.player.stack += hand.bet
-                result = f'Push hand (both have BJ)'
+                result = f'PUSH'
             elif hand.is_over is False and self.dealer.is_over is True:
                 self.player.stack += hand.bet * 2
-                result = f'Win (dealer > 21)'
+                result = f'WIN'
                 self._display_chips(hand)
             elif hand.is_over is True:
-                result = f'Lose (> 21)'
+                result = f'BUST'
                 self.hide_chips(hand)
                 self.hide(hand)
                 hand.bet = 0
             elif hand.sum < self.dealer.sum:
-                result = f'Lose ({hand.sum} vs {self.dealer.sum})'
+                result = f'LOSE ({hand.sum} vs {self.dealer.sum})'
                 self.hide_chips(hand)
                 self.hide(hand)
                 hand.bet = 0
@@ -229,11 +236,11 @@ class Game:
                 result = f'Lose by surrender'
             elif hand.sum > self.dealer.sum:
                 self.player.stack += hand.bet * 2
-                result = f'Win ({hand.sum} vs {self.dealer.sum})'
+                result = f'WIN ({hand.sum} vs {self.dealer.sum})'
                 self._display_chips(hand)
             elif hand.sum == self.dealer.sum:
                 self.player.stack += hand.bet
-                result = f'Push hand'
+                result = f'PUSH'
             else:
                 raise ValueError
             self.display_info(hand, result)
@@ -268,7 +275,7 @@ class Game:
         """Verifies player decision."""
         correct_play = get_correct_play(hand, self.dealer.cards[0], len(self.player.hands))
         if correct_play != play:
-            self.display_info(hand, 'Incorrect! Try again..')
+            self.display_info(hand, 'Try again!')
             self.gui.root.after(1000, self.clean_info)
             return False
         return True
@@ -340,7 +347,7 @@ class Game:
         """Cleans player card slots."""
         for slot in range(4):
             for n in range(N_CARDS_MAX):
-                self.gui.slot_player[f'{str(slot)}{str(n)}'].configure(image='', width=0)
+                self.gui.slot_player[f'{str(slot)}{str(n)}'].configure(image='', width=0, height=0)
 
     def clean_dealer_slots(self):
         """Cleans dealer slot."""
@@ -362,11 +369,13 @@ class Game:
             self.gui.slot_dealer[str(ind)].configure(image=img, width=width)
             self.gui.slot_dealer[str(ind)].image = img
 
-    def display_player_cards(self, hand: Hand):
+    def display_player_cards(self, hand: Hand, rotate_last: bool = False):
         """Displays cards of one hand."""
         for ind, card in enumerate(hand.cards):
-            img, width, _ = get_image(card)
-            self.gui.slot_player[f'{str(hand.slot)}{str(ind)}'].configure(image=img, width=width)
+            rotate = True if ind == len(hand.cards) - 1 and rotate_last is True else False
+            img, width, height = get_image(card, rotate=rotate)
+            self.gui.slot_player[f'{str(hand.slot)}{str(ind)}'].configure(image=img, width=width,
+                                                                          height=height)
             self.gui.slot_player[f'{str(hand.slot)}{str(ind)}'].image = img
 
     def display_player_hands(self):
@@ -411,12 +420,6 @@ class Game:
 
     def display_info(self, hand: Hand, info: str):
         """Prints text below hand."""
-        if hand.is_blackjack is True:
-            self.gui.info[str(hand.slot)].place(x=hand.slot * 250 + 20, y=585)
-        elif hand.bet in (self.bet, self.bet * 2, self.bet*4):
-            self.gui.info[str(hand.slot)].place(x=hand.slot * 250 + 20, y=555)
-        else:
-            self.gui.info[str(hand.slot)].place(x=hand.slot * 250 + 20, y=520)
         self.gui.info_text[str(hand.slot)].set(info)
 
     @staticmethod
@@ -424,9 +427,9 @@ class Game:
         return Shoe(6)
 
 
-def get_image(card: Card = None, width: int = 100, height: int = 130):
+def get_image(card: Card = None, width: int = 100, height: int = 130, rotate: bool = False):
     if card is None:
-        filename = 'blackjack_gui/images/back.png'
+        filename = f'{IMG_PATH}/back.png'
     else:
         prefix = {
             'A': 'ace',
@@ -438,24 +441,53 @@ def get_image(card: Card = None, width: int = 100, height: int = 130):
             fix = prefix[card.label]
         else:
             fix = str(card.value)
-        filename = f'blackjack_gui/images/{fix}_of_{card.suit}.png'
+        filename = f'{IMG_PATH}/{fix}_of_{card.suit}.png'
     image = Image.open(filename).resize((width, height), Image.ANTIALIAS)
+    if rotate is True:
+        image = image.resize((height, height))
+        image = image.rotate(angle=90)
+        image = image.resize((height, width))
+        width, height = height, width
     return ImageTk.PhotoImage(image), width, height
 
 
 def get_chip_image(color: str = 'red'):
     size = 50
-    filename = f'blackjack_gui/images/{color}-chip.png'
+    filename = f'{IMG_PATH}/{color}-chip.png'
     image = Image.open(filename).resize((size, size-15), Image.ANTIALIAS)
     return ImageTk.PhotoImage(image)
 
 
 def get_finger_image():
-    filename = f'blackjack_gui/images/finger2.png'
+    filename = f'{IMG_PATH}/finger2.png'
     image = Image.open(filename).resize((40, 60), Image.ANTIALIAS)
     return ImageTk.PhotoImage(image)
 
 
+def round_polygon(canvas, x, y, sharpness, **kwargs):
+    if sharpness < 2:
+        sharpness = 2
+    ratio_multiplier = sharpness - 1
+    ratio_divider = sharpness
+    points = []
+    for i in range(len(x)):
+        points.append(x[i])
+        points.append(y[i])
+        if i != (len(x) - 1):
+            points.append((ratio_multiplier*x[i] + x[i + 1])/ratio_divider)
+            points.append((ratio_multiplier*y[i] + y[i + 1])/ratio_divider)
+            points.append((ratio_multiplier*x[i + 1] + x[i])/ratio_divider)
+            points.append((ratio_multiplier*y[i + 1] + y[i])/ratio_divider)
+        else:
+            points.append((ratio_multiplier*x[i] + x[0])/ratio_divider)
+            points.append((ratio_multiplier*y[i] + y[0])/ratio_divider)
+            points.append((ratio_multiplier*x[0] + x[i])/ratio_divider)
+            points.append((ratio_multiplier*y[0] + y[i])/ratio_divider)
+            points.append(x[0])
+            points.append(y[0])
+    return canvas.create_polygon(points, **kwargs, smooth=tkinter.TRUE)
+
+
 def main(args):
     bc = '#4e9572'
     root = tkinter.Tk()
@@ -463,6 +495,11 @@ def main(args):
     root.title('Blackjack')
     root.configure(background=bc)
 
+    rect = tkinter.Canvas(root, bg=bc, height=100, width=80, bd=0, highlightthickness=0,
+                          relief='ridge')
+    rect.place(x=525, y=485)
+    round_polygon(rect, [5, 75, 75, 5], [5, 5, 90, 90], 10, width=4, outline="#bbb500", fill=bc)
+
     # Shoe status
     shoe_status_container = tkinter.Label(root, borderwidth=0, background='white')
     shoe_status_container.place(x=20, y=30, height=150, width=30)
@@ -482,11 +519,11 @@ def main(args):
     x_slot = 250
     padding_left = 20
     info_text = {str(slot): tkinter.StringVar(root) for slot in range(4)}
-    info = {str(slot): tkinter.Label(root, textvariable=info_text[str(slot)], font=20,
+    info = {str(slot): tkinter.Label(root, textvariable=info_text[str(slot)], font='helvetica 11 bold',
                                      borderwidth=0, background=bc, fg="white")
             for slot in range(4)}
     for ind, i in enumerate(info.values()):
-        i.place(x=ind*x_slot+padding_left, y=585)
+        i.place(x=ind*x_slot+padding_left+118, y=465)
 
     # Dealer finger
     finger = {str(slot): tkinter.Label(root, borderwidth=0, background=bc) for slot in range(4)}
